@@ -14,8 +14,9 @@ use ff:mpeg;
 mpeg::cut(23.32342, 50.234234, "nwt_43_Joh_ASL_03_r720P.mp4", "John_3-5.mp4"); // Slices the given video at the given time stamp and outputs to *John_3-5.mp4*.
 ```
 */
-use std::process::Command;
-pub fn cut(start_time: f64, end_time: f64, path: &str, output: &str) {
+use std::{path::Path, process::Command};
+
+pub fn cut(start_time: f64, end_time: f64, path: &Path, output: &str) {
     let command = Command::new("ffmpeg")
         .arg("-v")
         .arg("quiet")
